veyron/services/mgmt: port of binaryd integration test to Go

This CL ports the binaryd integration test from shell to Go. To
facilitate retrieval of the HTTP address used for URL-based binary
repository downloads, this CL adds a trivial implementation of the
DownloadURL RPC method.

Change-Id: I2e3b544241ae32fb9aa6daa821963aff5cd1e498
diff --git a/services/mgmt/binary/impl/setup.go b/services/mgmt/binary/impl/setup.go
index 12e43fa..2f96bf5 100644
--- a/services/mgmt/binary/impl/setup.go
+++ b/services/mgmt/binary/impl/setup.go
@@ -10,9 +10,9 @@
 
 const defaultRootPrefix = "veyron_binary_repository"
 
 // SetupRoot sets up the root directory if it doesn't already exist. If an
 // empty string is used as root, create a new temporary directory.
-func SetupRoot(root string) (string, error) {
+func SetupRootDir(root string) (string, error) {
 	if root == "" {
 		var err error
 		if root, err = ioutil.TempDir("", defaultRootPrefix); err != nil {
@@ -10,9 +10,9 @@
 const defaultRootPrefix = "veyron_binary_repository"
 
-// SetupRoot sets up the root directory if it doesn't already exist. If an
+// SetupRootDir sets up the root directory if it doesn't already exist. If an
 // empty string is used as root, create a new temporary directory.